package net.sourceforge.emaria.openfest;

import junit.framework.TestCase;
import junit.textui.TestRunner;
import net.sourceforge.emaria.openfest.Message;

public class MessageTest extends TestCase {

    public void testHelloWorld() {
        Message helloWorld = new Message();
	assertEquals(helloWorld.getMessage("Sharo"),
            "Hello World, Sharo");
        assertNotNull(helloWorld.getMessage(null));
    }

    public void testHelloWorldFails() {
    	Message helloWorld = new Message();
	assertEquals(helloWorld.getMessage("Sharo"),
	    "Hello World, OpenFest");
    }
}
