package net.sourceforge.emaria.openfest;

public class Main {

    public static void main(String[] args) {
        Message message = new Message();
	System.out.println(message.getMessage("Sharo"));
    }
}
